@@ -383,7 +383,7 @@ def set_inputs(newItkObject, args=[], kargs={}):
             raise AttributeError('No method found to set the input.')
 
     # named args : name is the function name, value is argument(s)
-    for attribName, value in kargs.iteritems():
+    for attribName, value in kargs.items():
         # use Set as prefix. It allow to use a shorter and more intuitive
         # call (Ex: itk.ImageFileReader.UC2.New(FileName='image.png')) than
         # with the full name
